﻿using Syncfusion.UI.Xaml.Diagram;
using Syncfusion.UI.Xaml.Diagram.Stencil;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace Stencil_142815
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            //Node collection
            diagram.Nodes = new ObservableCollection<INode>();

            diagram.Connectors = new ObservableCollection<Connector>();

            diagram.PortVisibility = PortVisibility.Visible;

            diagram.PageSettings.PageBackground = new SolidColorBrush(Colors.White);

            //creating and adding symbols into the collection
            symbolstencil.SymbolSource = new SymbolCollection()
             {
            
            AddSymbols("BPMNShapes", "Image", "Symbol3", this.Resources["FlowChart_StoredData"] as DataTemplate),
            AddSymbols("BPMNShapes", "Image", "Symbol4", this.Resources["FlowChart_Document"] as DataTemplate),
            AddSymbols("BPMNShapes", "Image", "Symbol15", this.Resources["FlowChart_Data"] as DataTemplate),
            AddSymbols("BPMNShapes", "Image", "Symbol6", this.Resources["FlowChart_InternalStorage"] as DataTemplate),
            AddSymbols("BPMNShapes", "Image", "Symbol7", this.Resources["FlowChart_PaperTape"] as DataTemplate),
            AddSymbols("BPMNShapes", "Image", "Symbol18", this.Resources["FlowChart_SequentialData"] as DataTemplate)
            
        };

            symbolstencil.SelectedFilter = new SymbolFilterProvider() { Content = "group", Filter = Filter };
            (diagram.Info as IGraphInfo).ItemAdded += MainWindow_ItemAdded;


        }

        void MainWindow_ItemAdded(object sender, ItemAddedEventArgs args)
        {
            if (args.ItemSource == ItemSource.Stencil)
            {
                var dropedItem = args.Item as INode;

                if (dropedItem != null)
                {
                    INodePort port1 = addPort(dropedItem, 0.5, 0.5);
                    dropedItem.Ports = new ObservableCollection<INodePort>()
                         {
                            port1
                         };

                }

            }

        }

        private INodePort addPort(INode node, double p1, double p2)
        {
            NodePort v = new NodePort()
            {
                Width = 11,
                Height = 11,
                NodeOffsetX = p1,
                NodeOffsetY = p2,
                Node=node,
                Shape = new EllipseGeometry() { RadiusX = 10, RadiusY = 10 },
                ShapeStyle = this.Resources["portstyle"] as Style,
               
            };
            return v;
        }

        //Adding Symbols
        public Symbols AddSymbols(string group, string symbol, string key, DataTemplate template)
        {
            Symbols a = new Symbols();
            a.GroupName = group;
            a.Symbol = symbol;
            a.Key = key;
            a.SymbolTemplate = template;
            return a;
        }


        private bool Filter(SymbolFilterProvider sender, ISymbol symbol)
        {
            return true;
        }
    }

    //Class derived from ISymbol
    public class Symbols : ISymbol
    {
        public Symbols()
        {

        }

        public object Symbol
        {
            get;
            set;
        }

        public object Key
        {
            get;
            set;
        }
        public DataTemplate SymbolTemplate
        {
            get;
            set;
        }
        public string GroupName { get; set; }
        public ISymbol Clone()
        {
            return new Symbols()
            {
                Symbol = this.Symbol,
                SymbolTemplate = this.SymbolTemplate,
                Key = this.Key
            };
        }
    }
    //Collection of ISymbol
    public class SymbolCollection : ObservableCollection<ISymbol>
    {

    }

}

